#ifndef rarp_h
#define rarp_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_rarp: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_rarp */
public:
	MODULE_rarp (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context, const char *key);
	int execmain (int argc, char *argv[], bool);
	int probe (int level, int , bool);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
    /*~PROTOEND~ MODULE_rarp */
};

#include "rarp.p"

#endif
